from setuptools import setup

setup(name = 'MM_BiGauss',
      version = '0.1',
      description = 'Binomial and Gaussian distributions',
      packages = ['MM_BiGauss'],
      author = 'MM',
      author_email = 'magy0620@yahoo.com',
      zip_safe = False)
